# CBpanel "CLOCK" plugin

name = "Clock"
description = "Draw a digital clock and print today's date on the panel"

import CBpanel, gtk, gobject, time

class CalendarWindow(CBpanel.PopupWindow):
    def __init__(self, panel, plugin):
        CBpanel.PopupWindow.__init__(self, panel)
        self.plugin = plugin
        #~ self.set_header("Calendar", "Browse the calendar", panel.get_image_from_icon_name("stock_calendar", 24))
        cal = gtk.Calendar()
        self.add(cal)
        cal.show()
        if self.plugin.settings.has_key("configure_command"):
            btn = gtk.Button()
            btn.set_name("EdgeButton")
            btn.connect("clicked", self.onConfigureDateTime)
            btn.set_relief(gtk.RELIEF_NONE)
            box = gtk.HBox(False, 2)
            btn.add(box)
            img = panel.get_stock_image(gtk.STOCK_PREFERENCES, 24)
            box.add(img)
            label = gtk.Label()
            panel.update_font(self, label)
            label.set_alignment(0.5, 0.5)
            label.set_markup("<span weight=\"bold\">Settings</span>")
            label.show()
            box.add(label)
            btn.show_all()
            #~ self.header.pack_end(btn, False)
            self.add(btn)

    def onConfigureDateTime(self, a):
        CBpanel.launch_command(self.plugin.settings['configure_command'])
        self.close()

class Plugin(CBpanel.Plugin):
    def __init__(self, panel, settings):
        CBpanel.Plugin.__init__(self, panel, settings)
        self.set_border_width(0)

        if panel.config.has_key('TIMEFORMAT'):
            self.format = "<span weight=\"bold\">%s</span>" % panel.config['TIMEFORMAT']
        else:
            self.format = "<span weight=\"bold\">%H:%M</span>"

        self.cwindow = CalendarWindow(panel, self)

        btn = gtk.ToggleButton()
        btn.set_name("EdgeButton")
        btn.connect("toggled", self.cwindow.toggle)
        btn.connect("enter-notify-event", self.cwindow.toggleConditional)
        btn.set_relief(gtk.RELIEF_NONE)
        btn.set_border_width(0)
        btn.set_focus_on_click(False)
        btn.set_property('can-focus', False)
        self.add(btn)

        box = gtk.VBox(False, 0)
        box.show()
        btn.add(box)

        self.label_time = gtk.Label()
        panel.update_font(self, self.label_time)
        self.label_time.set_alignment(0.5, 0.5)
        self.label_time.set_name("DigitLabel")
        self.label_time.show()

        self.update()

        box.add(self.label_time)

        if self.format.find("%c") >= 0 or \
                self.format.find("%S") >= 0 or \
                self.format.find("%T") >= 0 or \
                self.format.find("%X") >= 0:
            self.logDEBUG("Clock displaying seconds: update scheduled every second.")
            gobject.timeout_add(1000, self.update)
        else:
            self.logDEBUG("Clock not displaying seconds: updated scheduled once every minute.")
            gobject.timeout_add(60 * 1000, self.update)

    def update(self):
        try:
            now = time.localtime()
            self.label_time.set_markup(time.strftime('%s' % (self.format), now))
        except KeyboardInterrupt:
            pass
        return True
